# Academic Markdown CLI

This is the command line tool used in the
[academic_markdown](https://github.com/cochaviz/academic_markdown) project.
While there should be a discrete README for this project, for now I would like
to ask anyone to move there for more information on the project.
